#include "debug.h"
#include "debugfont.raw.c"
/*!
\addtogroup debug_functions Debug Functions
*/
/*+----------------------------------------------------------------------------------------------+*/
#ifndef DOXYGEN_SHOULD_SKIP_THIS
static u32 *s_pFrameBuffer;
static u32 s_Color;
static u8 *s_pLetterPointer[256];
static char s_Abc[95]=
" !\"#$\%&'()*+,-./0123456789:;<=>?@abcdefghijklmnopqrstuvwxyz[]ABCDEFGHIJKLMNOPQRSTUVWXYZ+|";
#endif /* DOXYGEN_SHOULD_SKIP_THIS */
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Set debugtext-system framebuffer address

\param pFrameBuffer
   Pointer to the framebuffer, where the debug textsystem shall write to.

*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_SetFrameBuffer(u32 *pFrameBuffer)
{
   s_pFrameBuffer = pFrameBuffer;
}
/*+----------------------------------------------------------------------------------------------+*/
#ifndef DOXYGEN_SHOULD_SKIP_THIS
// Helper function for DEBUG_Print stuff
int StrLen(char *pText)
{
   int iCnt=0;

   while(*pText++ != '\0') iCnt++;

   return iCnt;
}
#endif /* DOXYGEN_SHOULD_SKIP_THIS */
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Set debugtext-system font color

\param Color
   Debug-font-color. Specify it as YCbYCr value.

\sa
   COLOR_ConvertRgb2YCbYCr()
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_SetTextColor(u32 Color)
{
   s_Color = Color;
}
/*+----------------------------------------------------------------------------------------------+*/
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Init debug-onscreen-text-system

\param pFrameBuffer
   Pointer to the framebuffer, where the debug textsystem shall write to.

\param Color
   Debug-font-color. Specify it as YCbYCr value.

\sa
   DEBUG_Print()           \n
   DEBUG_ShowValueU8()     \n
   DEBUG_ShowValueU16()    \n
   DEBUG_ShowValueU32()    \n
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_InitText(u32 *pFrameBuffer, u32 Color)
{
   int i;
   int iAbcLen=sizeof(s_Abc);

   for(i=0; i<256; i++)
   {
      s_pLetterPointer[i] = NULL;
   }

   for(i=0; i<iAbcLen; i++)
   {
      if(NULL == s_pLetterPointer[(u8)s_Abc[i]])
      {
         s_pLetterPointer[(u8)s_Abc[i]] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*i];
      }
   }

   // all unsupported chars force to be a space character
   for(i=0; i<256; i++)
   {
      if(NULL == s_pLetterPointer[i])
      {
         s_pLetterPointer[i] = s_pLetterPointer[' '];
      }
   }

   s_pLetterPointer[0x0] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(16)]; // 0
   s_pLetterPointer[0x1] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(17)]; // 1
   s_pLetterPointer[0x2] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(18)]; // 2
   s_pLetterPointer[0x3] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(19)]; // 3
   s_pLetterPointer[0x4] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(20)]; // 4
   s_pLetterPointer[0x5] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(21)]; // 5
   s_pLetterPointer[0x6] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(22)]; // 6
   s_pLetterPointer[0x7] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(23)]; // 7
   s_pLetterPointer[0x8] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(24)]; // 8
   s_pLetterPointer[0x9] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(25)]; // 9

   s_pLetterPointer[0xa] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(33)]; // a
   s_pLetterPointer[0xb] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(34)]; // b
   s_pLetterPointer[0xc] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(35)]; // c
   s_pLetterPointer[0xd] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(36)]; // d
   s_pLetterPointer[0xe] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(37)]; // e
   s_pLetterPointer[0xf] = (u8*)&DEBUG_FontBitmap[DEBUG_TEXT_CHAR_SIZE*(38)]; // f

   DEBUG_SetFrameBuffer (pFrameBuffer);
   DEBUG_SetTextColor   (Color);
}
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Show an u8 on screen

\param x
   Horizontal Screen Coordinate

\param y
   Vertical Screen Coordinate

\param ValueToShow
   The 8bit value you want to display on screen

\sa
   DEBUG_Print()           \n
   DEBUG_ShowValueU16()    \n
   DEBUG_ShowValueU32()    \n
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_ShowValueU8(short x, short y, u8 ValueToShow)
{
   int xx,yy, act=0;
   u8 *pLetter=NULL;
   u8 _1, _2;

   ValueToShow &= 0xff;

   _1 = (u8)(ValueToShow>>4);
   _2 = (u8)(ValueToShow&0xf);

   pLetter = s_pLetterPointer[_1];

   for(yy=0; yy<DEBUG_TEXT_CHAR_HEIGHT; yy++)
   {
      for(xx=0; xx<DEBUG_TEXT_CHAR_WIDTH; xx++)
      {
         if(0 != pLetter[act])
         {
            s_pFrameBuffer[(320*(y+yy))+((xx+x)>>1)] = s_Color;
         }
         act++;
      }
   }

   act=0;
   _1 = (u8)(ValueToShow>>4);
   _2 = (u8)(ValueToShow&0xf);

   pLetter = s_pLetterPointer[_2];

   for(yy=0; yy<DEBUG_TEXT_CHAR_HEIGHT; yy++)
   {
      for(xx=0; xx<DEBUG_TEXT_CHAR_WIDTH; xx++)
      {
         if(0 != pLetter[act])
         {
            s_pFrameBuffer[(320*(y+yy))+((xx+x+DEBUG_TEXT_CHAR_WIDTH)>>1)] = s_Color;
         }
         act++;
      }
   }
}
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Show an u16 on screen

\param x
   Horizontal Screen Coordinate

\param y
   Vertical Screen Coordinate

\param ValueToShow
   The 16bit value you want to display on screen

\sa
   DEBUG_Print()           \n
   DEBUG_ShowValueU8()     \n
   DEBUG_ShowValueU32()    \n
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_ShowValueU16(short x, short y, u16 ValueToShow)
{
   u8 _1, _2;

   ValueToShow &= 0xffff;

   _1 = DEBUG_GET_1ST_U8_FROM_U16(ValueToShow);
   _2 = DEBUG_GET_2ND_U8_FROM_U16(ValueToShow);

   DEBUG_ShowValueU8(   x, y, _1);
   DEBUG_ShowValueU8(32+x, y, _2);
}
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Show an u32 on screen

\param x
   Horizontal Screen Coordinate

\param y
   Vertical Screen Coordinate

\param ValueToShow
   The 32bit value you want to display on screen

\sa
   DEBUG_Print()           \n
   DEBUG_ShowValueU16()    \n
   DEBUG_ShowValueU32()    \n
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_ShowValueU32(short x, short y, u32 ValueToShow)
{
   u16 _1, _2;

   ValueToShow &= 0xffffffff;

   _1 = DEBUG_GET_1ST_U16_FROM_U32(ValueToShow);
   _2 = DEBUG_GET_2ND_U16_FROM_U32(ValueToShow);

   DEBUG_ShowValueU16(   x, y, _1);
   DEBUG_ShowValueU16(64+x, y, _2);
}
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Print a single char to screen

\param x
   Horizontal Screen Coordinate

\param y
   Vertical Screen Coordinate

\param CharToPrint
   The char/letter you want to print

\sa
   DEBUG_Print()
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_PrintChar(short x, short y, char CharToPrint)
{
   int xx,yy, act=0;
   u8 *pLetter=NULL;

   pLetter = s_pLetterPointer[CharToPrint];

   for(yy=0; yy<DEBUG_TEXT_CHAR_HEIGHT; yy++)
   {
      for(xx=0; xx<DEBUG_TEXT_CHAR_WIDTH; xx++)
      {
         if(0 != pLetter[act])
         {
            s_pFrameBuffer[(320*(y+yy))+((xx+x)>>1)] = s_Color;
         }
         act++;
      }
   }
}
/*+----------------------------------------------------------------------------------------------+*/
/*!
\ingroup debug_functions
\brief Print text to screen

\param x
   Horizontal Screen Coordinate

\param y
   Vertical Screen Coordinate

\param pText
   Pointer to a NULL-terminated text

\note
   This function is quite <b>slow</b> and should be used only for debug purposes. \n \n

   It supports the following characters: \n
      -  !"#$%&'()*+,-./0123456789:;<=>?@abcdefghijklmnopqrstuvwxyz[]ABCDEFGHIJKLMNOPQRSTUVWXYZ+| \n

   In case you specify an unsupported character, this character will not be displayed then.
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void DEBUG_Print(short x, short y, char *pText)
{
   int i;

   for(i=0; i<StrLen(pText); i++)
   {
      if(' ' != pText[i])
      {
         DEBUG_PrintChar(x+(i*DEBUG_TEXT_CHAR_WIDTH), y, pText[i]);
      }
   }
}
/*+----------------------------------------------------------------------------------------------+*/


/* END OF FILE */
