#include "memcard.h"
/*!
\addtogroup memcard_functions Memory-Card Functions
*/
/*+----------------------------------------------------------------------------------------------+*/
/*
   Here comes some MEM Card related stuff.

   I tested in with the MEM Card either in slot A or slot B.

   I can't test if these values differ when both are mem-cards
   are connected, because i only have one.

   Anyway, i think it's a beginning :)

   So, these are the values which change, when one of the cards
   getting removed.

+---
   This is the value when the GC has been booted with a pad pluged in.
   Booted with MEM Card in Slot A Value >>> 0x00003008 <<<
+---
   Once it was removed and pluged in again, it looks like these:


   Address         MEM Card 1 connected    MEM Card 1 removed
   ----------      -------------------     ------------------
   0xCC006800      0x00003808              0x00002808
   0xCC006840      0x00003808              0x00002808
   0xcc006880      0x00003808              0x00002808
   0xCC0068C0      0x00003808              0x00002808
   0xCC006900      0x00003808              0x00002808
   0xcc006940      0x00003808              0x00002808
   0xCC006980      0x00003808              0x00002808
   0xCC0069C0      0x00003808              0x00002808
   0xCC006A00      0x00003808              0x00002808
   0xCC006A40      0x00003808              0x00002808
   0xCC006A80      0x00003808              0x00002808
   0xCC006AC0      0x00003808              0x00002808
   0xCC006B00      0x00003808              0x00002808
   0xCC006B40      0x00003808              0x00002808
   0xCC006B80      0x00003808              0x00002808
   0xCC006BC0      0x00003808              0x00002808

   ----------------------------------------------------------

   Booted with MEM Card in Slot B: ????????

   Address         MEM Card 2 connected    MEM Card 2 removed
   ----------      -------------------     ------------------
   0xcc006814      0x00001800              0x00000800
   0xCC006854      0x00001800              0x00000800
   0xCC006894      0x00001800              0x00000800
   0xCC0068D4      0x00001800              0x00000800
   0xCC006914      0x00001800              0x00000800
   0xCC006954      0x00001800              0x00000800
   0xCC006994      0x00001800              0x00000800
   0xCC0096D4      0x00001800              0x00000800
   0xCC006A14      0x00001800              0x00000800
   0xCC006A54      0x00001800              0x00000800
   0xCC006A94      0x00001800              0x00000800
   0xCC006AD4      0x00001800              0x00000800
   0xCC006B14      0x00001800              0x00000800
   0xCC006B54      0x00001800              0x00000800
   0xCC006B94      0x00001800              0x00000800
   0xCC006BD4      0x00001800              0x00000800
*/
/*!
\ingroup memcard_functions
\brief Check if a memory card is available

\param SlotNo
   Specifies the slot number where you want to get the info from. \n\n
   <i>SlotNo</i> can be one of these defines:
      - ::MEMCARD_SLOT_A
      - ::MEMCARD_SLOT_B

\return
   - TRUE when the memory-card in the specified slot is available
   - FALSE when memory-card in the specified slot is <b>not</b> available


\bug It does not work 100%. It works only, when the memcard was removed once. :/
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 22nd June 2003
*/
u8 MEMCARD_IsCardAvailable(u32 SlotNo)
{
   switch(SlotNo)
   {
      case MEMCARD_SLOT_A:
               return ((*(u32*)0xCC006800 & 0x0000ffff) == 0x3808);

      case MEMCARD_SLOT_B:
               return ((*(u32*)0xcc006814 & 0x0000ffff) == 0x1800);
   }
}








/*+----------------------------------------------------------------------------------------------+*/

/* END OF FILE */
