#include "pad.h"
/*!
\addtogroup pad_functions Pad Functions
*/


/*!
\ingroup pad_functions

\brief Read pad state

\param pPad
   Pointer to a ::PAD structure.

\param PadChannel
   The channel you want to read the pad-state from.   \n

   - You can specify for the PadChannel parameter one of these defines: \n
      - ::PAD_CHANNEL_0  \n
      - ::PAD_CHANNEL_1  \n
      - ::PAD_CHANNEL_2  \n
      - ::PAD_CHANNEL_3  \n \n

A pad-channel represents one of the joystick ports. \n

After calling this function, the structure specified in pPad will hold the required information.

\sa ::PAD
*/
/*
   Author: Peter (www.console-dev.de)
   Date..: 20th June 2003
*/
void PAD_ReadState(PAD *pPad, u8 PadChannel)
{
   u32 Value32[3];
   u16 Value16[2];
   u8 Value8[2];
   s8 ValueS8[2];
   //u32 PadChannelAddr = 0xCC006400 + (PadChannel*12);
   u32 PadChannelAddr = MEM_PAD_CHANNEL(PadChannel); /* added in 0.2 */
   PAD_BUTTONS_DIGITAL *pDigital=&pPad->Digital;

   Value32[0] = *(u32 *)(PadChannelAddr+0);
   Value32[1] = *(u32 *)(PadChannelAddr+4);
   Value32[2] = *(u32 *)(PadChannelAddr+8);

   // digital buttons
   Value8[0] = (Value32[1] >> 16);
   Value8[1] = (Value32[1] >> 16) >> 8;

   // digital buttons
   pDigital->Left  = Value8[0] & 0x01;
   pDigital->Right = Value8[0] & 0x02;
   pDigital->Down  = Value8[0] & 0x04;
   pDigital->Up    = Value8[0] & 0x08;

   pDigital->Z     = Value8[0] & 0x10;
   pDigital->L     = Value8[0] & 0x20;
   pDigital->R     = Value8[0] & 0x40;

   pDigital->A     = Value8[1] & 0x01;
   pDigital->B     = Value8[1] & 0x02;
   pDigital->X     = Value8[1] & 0x04;
   pDigital->Y     = Value8[1] & 0x08;

   pDigital->Start = Value8[1] & 0x10;


   // analog stick
   ValueS8[0] = ((Value32[1]) & 0xff);
   ValueS8[1] = ((Value32[1]) & 0xff00) >> 8;

   pPad->Analog.X = 0x80+ValueS8[1];
   pPad->Analog.Y = 0x80-ValueS8[0];


   // trigger L and R
   Value8[0] = ((Value32[2]) & 0xff);
   Value8[1] = ((Value32[2]) & 0xff00) >> 8;

   pPad->Trigger.L = Value8[0];
   pPad->Trigger.R = Value8[1];


   // analoc C stick
   ValueS8[0] = (Value32[2] >> 16);
   ValueS8[1] = (Value32[2] >> 16) >> 8;

   pPad->AnalogC.X = 0x80+ValueS8[1];
   pPad->AnalogC.Y = 0x80-ValueS8[0];
}
/*+----------------------------------------------------------------------------------------------+*/



/* END OF FILE */
